@@ -25,14 +25,6 @@
 #include <Python.h>
 #include "sourcescanner.h"
 
-#ifdef _WIN32
-#include <fcntl.h>
-#include <io.h>
-#define WIN32_LEAN_AND_MEAN
-#define STRICT
-#include <windows.h>
-#endif
-
 #include <glib-object.h>
 
 #ifndef Py_TYPE
@@ -89,7 +81,7 @@ typedef struct {
 
 NEW_CLASS (PyGISourceSymbol, "SourceSymbol", GISourceSymbol, 10);
 NEW_CLASS (PyGISourceType, "SourceType", GISourceType, 9);
-NEW_CLASS (PyGISourceScanner, "SourceScanner", GISourceScanner, 8);
+NEW_CLASS (PyGISourceScanner, "SourceScanner", GISourceScanner, 9);
 
 
 /* Symbol */
@@ -441,104 +433,12 @@ static PyObject *
 pygi_source_scanner_parse_file (PyGISourceScanner *self,
 				PyObject          *args)
 {
-  int fd;
-  FILE *fp;
+  char *filename;
 
-  if (!PyArg_ParseTuple (args, "i:SourceScanner.parse_file", &fd))
+  if (!PyArg_ParseTuple (args, "s:SourceScanner.parse_file", &filename))
     return NULL;
 
-#ifdef _WIN32
-  /* The file descriptor passed to us is from the C library Python
-   * uses. That is msvcr71.dll for Python 2.5 and msvcr90.dll for
-   * Python 2.6, 2.7, 3.2 etc; and msvcr100.dll for Python 3.3 and 3.4.
-   * Python 3.5 and later is built with Visual Studio 2015, which uses
-   * the universal CRT, so we need to deal with urtbase.dll here instead.
-   * This code, at least if compiled with mingw, uses
-   * msvcrt.dll, so we cannot use the file descriptor directly. So
-   * perform appropriate magic.
-   */
-
-  /* If we are using the following combinations,
-   * we can use the file descriptors directly
-   * (Not if a build using WDK is used):
-   * Python 2.6.x/2.7.x with Visual C++ 2008
-   * Python 3.1.x/3.2.x with Visual C++ 2008
-   * Python 3.3.x/3.4.x with Visual C++ 2010
-   */
-
-  /* XXX: Somehow we cannot use the FD directly on Python 3.5+ even when
-   *      using Visual Studio 2015, so we currently need to use _get_osfhandle() when
-   *      in all cases on Python 3.5+
-   */
-
-#if (defined(_MSC_VER) && !defined(USE_WIN_DDK))
-#if (PY_MAJOR_VERSION==2 && PY_MINOR_VERSION>=6 && (_MSC_VER >= 1500 && _MSC_VER < 1600))
-#define MSVC_USE_FD_DIRECTLY 1
-#elif (PY_MAJOR_VERSION==3 && PY_MINOR_VERSION<=2 && (_MSC_VER >= 1500 && _MSC_VER < 1600))
-#define MSVC_USE_FD_DIRECTLY 1
-#elif (PY_MAJOR_VERSION==3 && PY_MINOR_VERSION<=4 && (_MSC_VER >= 1600 && _MSC_VER < 1700))
-#define MSVC_USE_FD_DIRECTLY 1
-#endif
-#endif
-
-#if !defined(MSVC_USE_FD_DIRECTLY) && !defined(__MINGW64_VERSION_MAJOR)
-  {
-#if defined(PY_MAJOR_VERSION) && PY_MAJOR_VERSION==2 && PY_MINOR_VERSION==5
-#define PYTHON_MSVCRXX_DLL "msvcr71.dll"
-#elif defined(PY_MAJOR_VERSION) && PY_MAJOR_VERSION==2 && PY_MINOR_VERSION==7
-#define PYTHON_MSVCRXX_DLL "msvcr90.dll"
-#elif defined(PY_MAJOR_VERSION) && PY_MAJOR_VERSION==3 && PY_MINOR_VERSION<=2
-#define PYTHON_MSVCRXX_DLL "msvcr90.dll"
-#elif defined(PY_MAJOR_VERSION) && PY_MAJOR_VERSION==3 &&  PY_MINOR_VERSION<=4
-#define PYTHON_MSVCRXX_DLL "msvcr100.dll"
-#elif defined(PY_MAJOR_VERSION) && PY_MAJOR_VERSION==3 && PY_MINOR_VERSION>=5
-#define PYTHON_MSVCRXX_DLL "ucrtbase.dll"
-#else
-#error This Python version not handled
-#endif
-    HMODULE msvcrxx;
-    intptr_t (*p__get_osfhandle) (int);
-    HANDLE handle;
-
-    msvcrxx = GetModuleHandle (PYTHON_MSVCRXX_DLL);
-    if (!msvcrxx)
-    {
-      g_print ("No " PYTHON_MSVCRXX_DLL " loaded.\n");
-      return NULL;
-    }
-
-    p__get_osfhandle = (intptr_t (*) (int)) GetProcAddress (msvcrxx, "_get_osfhandle");
-    if (!p__get_osfhandle)
-    {
-      g_print ("No _get_osfhandle found in " PYTHON_MSVCRXX_DLL ".\n");
-      return NULL;
-    }
-
-    handle = (HANDLE) p__get_osfhandle (fd);
-    if (!p__get_osfhandle)
-    {
-      g_print ("Could not get OS handle from " PYTHON_MSVCRXX_DLL " fd.\n");
-      return NULL;
-    }
-
-    fd = _open_osfhandle ((intptr_t) handle, _O_RDONLY);
-    if (fd == -1)
-    {
-      g_print ("Could not open C fd from OS handle.\n");
-      return NULL;
-    }
-  }
-#endif
-#endif
-
-  fp = fdopen (fd, "r");
-  if (!fp)
-    {
-      PyErr_SetFromErrno (PyExc_OSError);
-      return NULL;
-    }
-
-  if (!gi_source_scanner_parse_file (self->scanner, fp))
+  if (!gi_source_scanner_parse_file (self->scanner, filename))
     {
       g_print ("Something went wrong during parsing.\n");
       return NULL;
@@ -589,37 +489,54 @@ pygi_source_scanner_set_macro_scan (PyGISourceScanner *self,
 static PyObject *
 pygi_source_scanner_get_symbols (PyGISourceScanner *self, G_GNUC_UNUSED PyObject *unused)
 {
-  GSList *l, *symbols;
+  GPtrArray *symbols;
   PyObject *list;
-  int i = 0;
+  guint i = 0;
 
   symbols = gi_source_scanner_get_symbols (self->scanner);
-  list = PyList_New (g_slist_length (symbols));
+  list = PyList_New (symbols->len);
 
-  for (l = symbols; l; l = l->next)
+  for (i = 0; i != symbols->len; ++i)
     {
-      PyObject *item = pygi_source_symbol_new (l->data);
-      PyList_SetItem (list, i++, item);
+      PyObject *item = pygi_source_symbol_new (g_ptr_array_index (symbols, i));
+      PyList_SetItem (list, i, item);
+    }
+
+  return list;
+}
+
+static PyObject *
+pygi_source_scanner_get_errors (PyGISourceScanner *self, G_GNUC_UNUSED PyObject *unused)
+{
+  GPtrArray *errors;
+  PyObject *list;
+  guint i = 0;
+
+  errors = gi_source_scanner_get_errors (self->scanner);
+  list = PyList_New (errors->len);
+
+  for (i = 0; i != errors->len; ++i)
+    {
+      PyObject *item = PyUnicode_FromString (g_ptr_array_index (errors, i));
+      PyList_SetItem (list, i, item);
     }
 
-  g_slist_free (symbols);
-  Py_INCREF (list);
   return list;
 }
 
 static PyObject *
 pygi_source_scanner_get_comments (PyGISourceScanner *self, G_GNUC_UNUSED PyObject *unused)
 {
-  GSList *l, *comments;
+  GPtrArray *comments;
   PyObject *list;
-  int i = 0;
+  guint i = 0;
 
   comments = gi_source_scanner_get_comments (self->scanner);
-  list = PyList_New (g_slist_length (comments));
+  list = PyList_New (comments->len);
 
-  for (l = comments; l; l = l->next)
+  for (i = 0; i != comments->len; ++i)
     {
-      GISourceComment *comment = l->data;
+      GISourceComment *comment = g_ptr_array_index (comments, i);
       PyObject *comment_obj;
       PyObject *filename_obj;
       PyObject *item;
@@ -651,18 +568,17 @@ pygi_source_scanner_get_comments (PyGISourceScanner *self, G_GNUC_UNUSED PyObjec
         }
 
       item = Py_BuildValue ("(OOi)", comment_obj, filename_obj, comment->line);
-      PyList_SetItem (list, i++, item);
+      PyList_SetItem (list, i, item);
 
       Py_DECREF (comment_obj);
       Py_DECREF (filename_obj);
     }
 
-  g_slist_free (comments);
-  Py_INCREF (list);
   return list;
 }
 
 static const PyMethodDef _PyGISourceScanner_methods[] = {
+  { "get_errors", (PyCFunction) pygi_source_scanner_get_errors, METH_NOARGS },
   { "get_comments", (PyCFunction) pygi_source_scanner_get_comments, METH_NOARGS },
   { "get_symbols", (PyCFunction) pygi_source_scanner_get_symbols, METH_NOARGS },
   { "append_filename", (PyCFunction) pygi_source_scanner_append_filename, METH_VARARGS },
